const shelljs = require('shelljs');
const chalk = require('chalk');
const fs = require('fs');
const path = require('path')
const debug = require('debug')('cmd:generator')
const question = require('./generator/plugin');
const moment = require('moment');

const SYS_TEMPLATE_PATH_MAP = {
  plugin: {
    name: 'plugin-template',
    path: path.resolve(__dirname, '../generator/plugin-template')
  },
  scaffold: {
    name: 'scaffold-template',
    path: path.resolve(__dirname, '../generator/scaffold-template')
  }
}

const REGISTRY_MAP = {
  npm: 'https://registry.npmjs.org/',
  tnpm: 'https://registry.npm.alibaba-inc.com'
}

module.exports = function(client){
  client
  .registryCommand('generator')
  .alias('g')
  .description(chalk.bold.blue('system cmd: create plugin generator'))
  .action(() => {
    this.prompt(question).then(answer => {
      const { name, command, template, description, registry } = answer;
      const options = {
        moment,
        config: JSON.parse(process.env.config),
        answer: {
          name,
          command,
          description,
          template,
          registry,
          registryPath: REGISTRY_MAP[registry]
        }
      }
      
      client.createGenerator({
        async configuring() {
          return {
            origin: SYS_TEMPLATE_PATH_MAP[template].path,
            target: `./${name}`
          }
        },
        async writing() {
          this.fs.copyTpl(this.templatePath('index.ejs'), this.destinationPath('index.js'), options);
          this.fs.copyTpl(this.templatePath('package.ejs'), this.destinationPath('package.json'), options);
          this.fs.copyTpl(this.templatePath('readme.ejs'), this.destinationPath('readme.md'), options);
          this.fs.copyTpl(this.templatePath('test/index.test.ejs'), this.destinationPath('test/index.test.js'), options);
          
          this.fs.copy(this.templatePath('babel.config.js'), this.destinationPath('babel.config.js'));
          this.fs.copy(this.templatePath('gitignore'), this.destinationPath('.gitignore'));
          this.fs.copy(this.templatePath('jest.config.js'), this.destinationPath('jest.config.js'));
          this.fs.copy(this.templatePath('LICENSE.md'), this.destinationPath('LICENSE.md'));

         if (template === 'scaffold') {
          this.fs.copyTpl(this.templatePath('develop.ejs'), this.destinationPath('develop.md'), options);
          this.fs.copy(this.templatePath('templates/**/*'), this.destinationPath('templates'))
         }
         
        },
        async end() {
          this.log.success(`${name}: ${template} is finish`)
        }
      })
    })
  });
} 