const shelljs = require('shelljs');
const chalk = require('chalk');
const debug = require('debug')('cmd:publish');
const emoji = require('node-emoji');
const config = JSON.parse(process.env.config);
const WHITE_LIST = config.WHITE_LIST;
const brandName = config.brandName;


const REGISTRY_MAP = {
  npm: 'https://registry.npmjs.org/',
  tnpm: 'https://registry.npm.alibaba-inc.com'
}

module.exports = function(client) {
  client
  .registryCommand('publish')
  .alias('p')
  .description(chalk.bold.blue('system cmd: publish plugin'))
  .action(() => {
    const pluginName = this.rootGeneratorName();
    debug('pluginName, %s', pluginName);
    if (this.isPluginName(pluginName)) {
      const question = [{
        type: 'list',
        name: 'npmClient',
        message: 'Which npmClient do you want to publish ?',
        choices: [
          'npm',
          'tnpm'
        ]
      }];
      
      this.prompt(question).then(answer => {
        const info = this.readPackageInfo();
        const package = this.fs.readJSON(info.path);
        package.publishConfig = {
          registry: REGISTRY_MAP[answer.npmClient]
        }
        debug('package publish config %o', package);
        this.fs.writeJSON(info.path, package);
        this.log.info(emoji.get(':rocket:') + ' start publish, Wait a minute...');
        shelljs.exec(`${answer.npmClient} publish`);
      });
    } else {
      this.log.error(`plugin name ${pluginName} is illegal, example: ${brandName}-plugin-xx, ${WHITE_LIST.map(prefix => prefix + '/' + brandName + '-plugin-xx').join(', ')}`)
    }
    
  });
}