/**
 * ----------------------------------
 * @file log.js
 * @desc 日志记录
 * @author Matrix <fangbo.fb@alibaba-inc.com>
 * @create: 2018/6
 * ----------------------------------
 */
const chalk = require('chalk');
const lodash = require('lodash');

const COLOR_CONFIG_MAP = {
  log: 'white',
  error: 'red',
  info: 'green',
  success: 'blue',
  warn: 'yellow'
}

const log = {
  _log(args, type) {
    
    console.log.apply(null, args.map(arg => {
      if (lodash.isString(arg)) {
        return chalk[COLOR_CONFIG_MAP[type]](arg)
      } else {
        return chalk[COLOR_CONFIG_MAP[type]](JSON.stringify(arg));
      }
    }))
  },
  log(...args) {
    log._log(args, 'log')
  },
  error(...args) {
    log._log(args, 'error')
  },
  info(...args) {
    log._log(args, 'info')
  },
  warn(...args) {
    log._log(args, 'warn')
  },
  success(...args) {
    log._log(args, 'success')
  }
}

const superLog = function(...args) {
  log.log(...args)
}


module.exports = lodash.extend(superLog, log);